@@ -3,10 +3,9 @@ from pathlib import Path
 
 import pytest
 from pymultirole_plugins.v1.schema import Document
-from starlette.responses import Response
 
 from pyformatters_textranksummarizer.textranksummarizer import (
-    TextRankSummarizerFormatter,
+    TextRankSummarizerProcessor,
     TextRankSummarizerParameters,
     TextRankAlgo,
 )
@@ -15,8 +14,8 @@ from pyformatters_textranksummarizer.textranksummarizer import (
 @pytest.mark.parametrize("algorithm", [a.value for a in TextRankAlgo])
 def test_textranksummarizer_french(algorithm):
     parameters = TextRankSummarizerParameters(algo=algorithm)
-    formatter = TextRankSummarizerFormatter()
-    doc = Document(
+    formatter = TextRankSummarizerProcessor()
+    original_doc = Document(
         text="""Un nuage de fumée juste après l’explosion, le 1er juin 2019.
         Une déflagration dans une importante usine d’explosifs du centre de la Russie a fait au moins 79 blessés samedi 1er juin.
         L’explosion a eu lieu dans l’usine Kristall à Dzerzhinsk, une ville située à environ 400 kilomètres à l’est de Moscou, dans la région de Nijni-Novgorod.
@@ -30,20 +29,18 @@ def test_textranksummarizer_french(algorithm):
         """,
         metadata={'language': 'fr'}
     )
-    resp: Response = formatter.format(doc, parameters)
-    assert resp.status_code == 200
-    assert resp.media_type == "text/plain"
-    summary = resp.body.decode(resp.charset)
+    doc = original_doc.copy(deep=True)
+    docs = formatter.process([doc], parameters)
+    summarized: Document = docs[0]
+    summary = summarized.text
+    assert len(summary) < len(original_doc.text)
 
     parameters.as_altText = "summary"
+    doc = original_doc.copy(deep=True)
     docs = formatter.process([doc], parameters)
     summarized: Document = docs[0]
-    assert summary == summarized.altTexts[0].text
-
-    parameters.as_altText = None
-    docs = formatter.process([doc], parameters)
-    summarized: Document = docs[0]
-    assert summary == summarized.text
+    summary = summarized.altTexts[0].text
+    assert len(summary) < len(original_doc.text)
 
 
 def test_textranksummarizer_french_with_sents():
@@ -54,15 +51,15 @@ def test_textranksummarizer_french_with_sents():
     doc = Document(**doc)
     ori_len = len(doc.text)
     parameters = TextRankSummarizerParameters(num_sentences=2)
-    formatter = TextRankSummarizerFormatter()
+    formatter = TextRankSummarizerProcessor()
     docs = formatter.process([doc], parameters)
     assert len(docs[0].text) < ori_len
 
 
 def test_textranksummarizer_english():
     parameters = TextRankSummarizerParameters(num_sentences=2)
-    formatter = TextRankSummarizerFormatter()
-    doc = Document(
+    formatter = TextRankSummarizerProcessor()
+    original_doc = Document(
         text="""The tower is 324 metres (1,063 ft) tall, about the same height as an 81-storey building, and the tallest structure in Paris.
     Its base is square, measuring 125 metres (410 ft) on each side. During its construction, the Eiffel Tower surpassed the Washington Monument to become the tallest man-made structure in the world, a title it held for 41 years until the Chrysler Building in New York City was finished in 1930.
     It was the first structure to reach a height of 300 metres. Due to the addition of a broadcasting aerial at the top of the tower in 1957, it is now taller than the Chrysler Building by 5.2 metres (17 ft).
@@ -70,17 +67,15 @@ def test_textranksummarizer_english():
         """,
         metadata={'language': 'en'}
     )
-    resp: Response = formatter.format(doc, parameters)
-    assert resp.status_code == 200
-    assert resp.media_type == "text/plain"
-    summary = resp.body.decode(resp.charset)
+    doc = original_doc.copy(deep=True)
+    docs = formatter.process([doc], parameters)
+    summarized: Document = docs[0]
+    summary = summarized.text
+    assert len(summary) < len(original_doc.text)
 
     parameters.as_altText = "summary"
+    doc = original_doc.copy(deep=True)
     docs = formatter.process([doc], parameters)
     summarized: Document = docs[0]
-    assert summary == summarized.altTexts[0].text
-
-    parameters.as_altText = None
-    docs = formatter.process([doc], parameters)
-    summarized: Document = docs[0]
-    assert summary == summarized.text
+    summary = summarized.altTexts[0].text
+    assert len(summary) < len(original_doc.text)
